import { AvatarDropdown, AvatarName, MenuBar } from '@/components';
import { postMenuGetMenu } from '@/services/system/Menu';
import { getUserGetUserInfo } from '@/services/system/User';
import fixMenuItemIcon from '@/utils/FixMenuItemIcon';
import { getAllRouteNameTile, replaceMenuWithRoutesData } from '@/utils/common';
import { addLocale } from '@@/plugin-locale';
import type { Settings as LayoutSettings } from '@ant-design/pro-components';
import { SettingDrawer } from '@ant-design/pro-components';
import { MenuDataItem } from '@ant-design/pro-layout';
import { RunTimeLayoutConfig, getLocale, history } from '@umijs/max';

import zhCN from '@/locales/zh-CN';
import cookie from 'react-cookies';
import { RequestConfig } from 'umi';
import defaultSettings from '../config/defaultSettings';
import './app.less';
import './base.less';
import { errorConfig } from './requestErrorConfig';

const isDev = true;
const loginPath = '/user/login';
const noCheckPath = ['/user/login'];

/**
 * @see  https://umijs.org/zh-CN/plugins/plugin-initial-state
 * */
export async function getInitialState(): Promise<{
  settings?: Partial<LayoutSettings>;
  currentUser?: API.CurrentUser;
  loading?: boolean;
  fetchUserInfo?: any;
  menuData?: MenuDataItem[];
}> {
  const fetchUserInfo = async () => {
    try {
      const msg = await getUserGetUserInfo();
      return msg.data.userInfo;
    } catch (error) {
      history.push(loginPath);
    }
    return undefined;
  };
  // 如果不是登录页面，执行
  const { location } = history;
  if (location.pathname !== loginPath && localStorage.getItem('access')) {
    // const currentUser = await fetchUserInfo();
    const menus = await postMenuGetMenu();
    // console.log('app_menus', replaceMenuWithRoutesData(menus.data.routes));
    if (getLocale() === 'zh-CN') {
      let localData = getAllRouteNameTile(menus.data.routes, '');
      let localRes: any = {};
      localData.forEach((v) => {
        // console.log(v.title,'localData_v')
        localRes[`menu${v.name}`] = v.title;
      });
      console.log(localRes, 'getAllRouteNameTile');
      addLocale('zh-CN', localRes, {
        momentLocale: 'zh-CN',
        antd: zhCN,
      });
    }

    return {
      fetchUserInfo,
      currentUser: await fetchUserInfo(),
      settings: {
        ...(defaultSettings as Partial<LayoutSettings>),
        // menuData: replaceMenuWithRoutesData(menus.data.routes),
      },
      menuData: replaceMenuWithRoutesData(menus.data.routes),
    };
  }

  return {
    fetchUserInfo,
    settings: defaultSettings as Partial<LayoutSettings>,
  };
}

// ProLayout 支持的api https://procomponents.ant.design/components/layout
export const layout: RunTimeLayoutConfig = ({ initialState, setInitialState }) => {
  // useEffect(() => {
  //   console.log('initialState', initialState);
  // }, []);
  return {
    actionsRender: () => [],
    footerRender: () => undefined,
    onPageChange: () => {
      const { location } = history;
      // 如果没有登录，重定向到 login
      console.log(location.pathname, 'location_pathname');
      if (!initialState?.currentUser && !noCheckPath.includes(location.pathname)) {
        history.push(loginPath);
      }
    },
    menu: {
      loading: initialState?.loading || false,
      locale: true,
      params: {
        userId: initialState?.currentUser?.id,
      },
      request: async () => {
        console.log(initialState, 'initialState_menuData');
        return initialState?.menuData || [];
      },
    },
    menuRender: () => undefined,
    menuDataRender: () => {
      if (initialState?.menuData !== undefined) {
        return fixMenuItemIcon(initialState?.menuData || []);
      }
    },
    bgLayoutImgList: [
      {
        src: 'https://mdn.alipayobjects.com/yuyan_qk0oxh/afts/img/D2LWSqNny4sAAAAAAAAAAAAAFl94AQBr',
        left: 85,
        bottom: 100,
        height: '303px',
      },
      {
        src: 'https://mdn.alipayobjects.com/yuyan_qk0oxh/afts/img/C2TWRpJpiC0AAAAAAAAAAAAAFl94AQBr',
        bottom: -68,
        right: -45,
        height: '303px',
      },
      {
        src: 'https://mdn.alipayobjects.com/yuyan_qk0oxh/afts/img/F6vSTbj8KpYAAAAAAAAAAAAAFl94AQBr',
        bottom: 0,
        left: 0,
        width: '331px',
      },
    ],
    links: [],
    // 自定义 403 页面
    // unAccessible: <div>unAccessible</div>,
    // 增加一个 loading 的状态
    childrenRender: (children) => {
      // if (initialState?.loading) return <PageLoading />;
      return (
        <div className="flex app_page_wrap">
          <MenuBar menuData={initialState?.menuData}></MenuBar>
          <div className="page_body">
            <div className="flex items-center justify-between body_nav_bar">
              {/* <h5>首页1 {initialState?.currentUser?.userName}</h5> */}
              <div>
                {initialState?.currentUser?.userName ? (
                  <AvatarDropdown menu={true}>
                    <div className="flex items-center cursor-pointer avatar_box">
                      <img
                        className="mr-[8px]"
                        src="https://img2.baidu.com/it/u=1374514083,943518806&fm=253&fmt=auto&app=138&f=PNG?w=500&h=500"
                      />
                      <AvatarName></AvatarName>
                    </div>
                  </AvatarDropdown>
                ) : (
                  <></>
                )}
              </div>
            </div>
            <div className="body_content">
              {children}
              {isDev && (
                <SettingDrawer
                  disableUrlParams
                  enableDarkTheme
                  settings={initialState?.settings}
                  onSettingChange={(settings) => {
                    setInitialState((preInitialState) => ({
                      ...preInitialState,
                      settings,
                    }));
                  }}
                />
              )}
            </div>
          </div>
        </div>
      );
    },
    ...initialState?.settings,
  };
};

const csrfAndJwtHeaderInterceptor = (url: string, options: RequestConfig) => {
  const csrfHeader = { 'X-CSRFToken': cookie.load('csrftoken') };
  let bearerToken = {};
  const access = localStorage.getItem('access');
  if (access) {
    bearerToken = { 'X-Token': `${access}` };
  }
  let locale = getLocale();
  return {
    url: `${url}`,
    options: {
      ...options,
      interceptors: true,
      headers: { ...csrfHeader, ...bearerToken, 'Accept-Language': locale },
    },
  };
};

const responseHeaderInterceptor = (response: Response) => {
  if ('new-token' in response.headers) {
    localStorage.setItem('access', (response.headers['new-token'] || '') as string);
    window.location.reload();
  }
  return response;
};

/**
 * @name request 配置，可以配置错误处理
 * 它基于 axios 和 ahooks 的 useRequest 提供了一套统一的网络请求和错误处理方案。
 * @doc https://umijs.org/docs/max/request#配置
 */
export const request = {
  ...errorConfig,
  requestInterceptors: [csrfAndJwtHeaderInterceptor],
  responseInterceptors: [responseHeaderInterceptor],
};
