/*
 * @Author: zhoux zhouxia@supervision.ltd
 * @Date: 2023-11-14 15:49:36
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-19 09:20:27
 * @FilePath: \general-ai-platform-web\src\components\TableActionCard\index.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */

import { Divider, Dropdown } from 'antd';
import React, { useEffect, useState } from 'react';
import { ReactComponent as MoreIcon } from '/public/home/more_icon.svg';

//TODO 表单的操作按钮集合 key的报错未解决
export type actionsProps = {
  key: string;
  renderDom: any;
  maxActionCount?: number;
};

export type TableActionItemProps = {
  renderActions: actionsProps[];
  listType?: 'proTable' | 'proList';
};

type actionItemProps = { key: string; label: any };

const TableActionCard: React.FC<TableActionItemProps> = (props) => {
  const [isHasMore, setIsHasMore] = useState(false);
  const [prevActions, setPrevActions] = useState<actionItemProps[]>([]);
  const [moreActions, setMoreActions] = useState<actionItemProps[]>([]);
  useEffect(() => {
    const { renderActions } = props;
    console.log(renderActions, 'renderActions');
    const maxActionCount = props?.maxActionCount || 3;
    if (renderActions && Array.isArray(renderActions)) {
      let startPrevActions: actionItemProps[] = [];
      let startMoreActions: actionItemProps[] = [];
      if (renderActions && renderActions.length <= maxActionCount) {
        startPrevActions = renderActions;
      } else {
        // eslint-disable-next-line array-callback-return
        renderActions.map((item, index) => {
          if (index < maxActionCount - 1) {
            startPrevActions.push(item);
          } else {
            startMoreActions.push({
              key: index + '',
              label: item.renderDom,
            });
          }
          // eslint-disable-next-line react/jsx-key
        });
      }

      if (startMoreActions?.length) {
        setIsHasMore(true);
      }
      setPrevActions(startPrevActions);
      setMoreActions(startMoreActions);
    }
  }, [props.renderActions]);

  return (
    <div className={`${props?.listType ? props?.listType : 'proTable'}ActionBox`}>
      {prevActions.map((item, index) => {
        return (
          <span
            key={item.key}
            style={props?.listType === 'proList' ? { paddingLeft: 8 } : { paddingRight: 0 }}
          >
            <span>{item.renderDom}</span>
            {index < prevActions.length - 1 ? <Divider type="vertical" /> : <></>}
          </span>
        );
      })}
      {isHasMore ? (
        <Dropdown
          menu={{ items: moreActions }}
          onMouseDown={(e) => e.stopPropagation()}
          getPopupContainer={(triggerNode) => triggerNode.parentNode}
        >
          <a className="ant-dropdown-link" onClick={(e) => e.stopPropagation()}>
            <MoreIcon />
          </a>
        </Dropdown>
      ) : (
        <></>
      )}
    </div>
  );
};

export default TableActionCard;
