/*
 * @Author: zhoux zhouxia@supervision.ltd
 * @Date: 2023-11-16 14:30:15
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-19 09:43:26
 * @FilePath: \general-ai-platform-web\src\components\BatchOperation\isBatchDelete.tsx
 * @Description: 删除确认
 */
// import { useIntl } from '@ant-design/pro-components';
import { DeleteOutlined } from '@ant-design/icons';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Button, Popconfirm } from 'antd';
import { proIconForTableActionStyle } from '../../../config/defaultIcon';

type IsDeleteProps = {
  // eslint-disable-next-line @typescript-eslint/ban-types
  buttonType?: 'defalut' | 'deleteIcon';
  deleteApi: () => void;
  deleteNextText?: string | React.ReactNode;
  handleContainerClick?: () => void;
};

const IsDelete: React.FC<IsDeleteProps> = (props) => {
  const intl = useIntl();
  // 包裹这层盒子是为了阻止向上事件冒泡
  const handleContainerClick = (e) => {
    e.stopPropagation();
  };
  return (
    <div onClick={handleContainerClick}>
      <Popconfirm
        key="destroy"
        placement="topLeft"
        title={intl.formatMessage({ id: 'common.tip.title', defaultMessage: '$$$' })}
        description={intl.formatMessage({
          id: 'common.modal.table.delete.content',
          defaultMessage: '$$$',
        })}
        okText={intl.formatMessage({ id: 'common.yes', defaultMessage: '$$$' })}
        cancelText={intl.formatMessage({ id: 'common.no', defaultMessage: '$$$' })}
        onConfirm={() => {
          props.deleteApi();
        }}
      >
        {props.buttonType === 'deleteIcon' ? (
          <span
            style={{
              color: 'rgba(232, 13, 13, 1)',
            }}
          >
            <DeleteOutlined
              style={{
                color: 'rgba(232, 13, 13, 1)',
                ...proIconForTableActionStyle,
              }}
            />
            <span>{props.deleteNextText}</span>
          </span>
        ) : (
          <Button type="link" size="small" danger>
            <FormattedMessage id="pages.searchTable.destroy" defaultMessage="Destroy" />
          </Button>
        )}
      </Popconfirm>
    </div>
  );
};

export default IsDelete;
