/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-04-07 15:25:23
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-17 10:57:27
 * @FilePath: \general-ai-manage\src\layouts\HomeLayout.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */
// import less from 'less';

import { AvatarDropdown, AvatarName } from '@/components';
import { Outlet, history, useIntl, useLocation } from '@umijs/max';
import { Layout, Radio } from 'antd';
import React, { useEffect, useState } from 'react';
// public/home/logo.svg

import { outerMenuRoute } from '../../config/routes';

import './homeLayout.less';

const { Header, Content } = Layout;

const HomeLayout: React.FC = () => {
  // const { initialState, setInitialState } = useModel('@@initialState');

  const intl = useIntl();
  const location = useLocation();
  const [currRoute, setCurrRoute] = useState<Record<string, any>>({});
  const [homeRoutes, setHomeRoutes] = useState<Record<string, any>[]>([]);

  /**设置当前菜单信息 */
  function fetchCurrRoute(record: Record<string, any>) {
    const currPath = record.path;
    setCurrRoute(() => {
      let subMenu;
      let startRoutes = outerMenuRoute.routes.filter((item) => item.path === currPath);
      if (startRoutes[0]?.level === 2) {
        // 二级菜单处理
        outerMenuRoute.routes.forEach((item) => {
          if (item.level === 1 && item?.subMenu) {
            item.subMenu?.forEach((subItem) => {
              if (subItem.path === currPath) {
                subMenu = item.subMenu;
              }
            });
          }
        });
      } else if (startRoutes[0]?.level === 1) {
        // 一级菜单
        subMenu = startRoutes[0]?.subMenu;
      }
      // console.log(outerMenuRoute.routes, subMenu, 'fetchCurrRoute_subMenu', startRoutes[0].level);
      return {
        subMenu,
        path: startRoutes[0]?.path,
        isHideMenu: startRoutes[0]?.isHideMenu,
      };
    });
  }

  const tabRouter = (record) => {
    console.log('tabRouter_record', record);
    const currRouteItem = record;
    history.push(currRouteItem.path);
  };
  // const modifyThemeColor = (color) => {
  //   less
  //     .modifyVars({
  //       '@primary-color': color,
  //     })
  //     .then(() => {
  //       console.log('主题色已更新');
  //     })
  //     .catch((error) => {
  //       console.error('更新主题色失败：', error);
  //     });
  // };
  // const handleThemeChange = (newTheme) => {
  //   setInitialState({
  //     ...initialState,
  //     settings: {
  //       ...initialState.settings,
  //       primaryColor: newTheme,
  //     },
  //   });
  // };
  useEffect(() => {
    // 调用 modifyThemeColor 方法，并传入新的主题色
    // handleThemeChange('red');
    // console.log('useEffect_less',less)
    // 当前路由高亮展示
    fetchCurrRoute({ path: location.pathname });
    setHomeRoutes(() => {
      const finalRoutes = outerMenuRoute.routes.filter((item) => item.level === 1);
      return finalRoutes;
    });
    console.log('useEffect_location', location);
  }, [location]);

  return (
    <div className="homeLayout_wrap">
      <Layout>
        {/* 一级菜单 */}
        <Header className="flex items-center justify-between">
          <div className="flex items-center">
            <div className="home_logo mr-[48px]"></div>
            <ul className="flex first_menu_box">
              {homeRoutes.map((menuItem) => {
                return (
                  // TODO 二级菜单切换一级菜单未能正常回显
                  <li
                    key={menuItem.key}
                    onClick={() => tabRouter(menuItem)}
                    className={[
                      currRoute?.path === menuItem.path ||
                      currRoute?.subMenu?.includes(currRoute?.path)
                        ? 'activeMenu'
                        : '',
                    ]}
                  >
                    {intl.formatMessage({ id: `menu.${menuItem.name}`, defaultMessage: '$$$' })}
                  </li>
                );
              })}
            </ul>
          </div>
          <div className="home_nav_action">
            <AvatarDropdown menu={true}>
              <div className="flex items-center cursor-pointer avatar_box">
                <img
                  className="mr-[8px] h-[40px]"
                  src="https://img2.baidu.com/it/u=1374514083,943518806&fm=253&fmt=auto&app=138&f=PNG?w=500&h=500"
                />
                <AvatarName></AvatarName>
              </div>
            </AvatarDropdown>
          </div>
        </Header>
        {/* 二级菜单 */}
        {/* //TODO 按UI图调整二级菜单栏效果 */}
        {currRoute?.subMenu && !currRoute?.isHideMenu && (
          <Radio.Group
            className="mx-[32px] mb-[12px]"
            defaultValue={currRoute?.path}
            buttonStyle="solid"
          >
            {currRoute.subMenu.map((menuItem) => {
              return menuItem?.isHideMenu ? (
                <></>
              ) : (
                <Radio.Button
                  value={menuItem.path}
                  key={menuItem.key}
                  onClick={() => tabRouter(menuItem)}
                  className={[currRoute?.path === menuItem.path ? 'activeMenu' : '']}
                >
                  <div className="flex justify-center items-center w-[120px]">
                    <div
                      className="mr-[4px]"
                      style={{ width: 14, height: 14, background: 'white' }}
                    ></div>
                    {intl.formatMessage({ id: `menu.${menuItem.name}`, defaultMessage: '$$$' })}
                    {currRoute?.isHideMenu}
                  </div>
                </Radio.Button>
              );
            })}
          </Radio.Group>
        )}
        <Content>
          <div className="home-layout-content">
            <Outlet></Outlet>
          </div>
        </Content>
        {/* <Footer style={{ textAlign: 'center' }}>苏胜天 ©2024</Footer> */}
      </Layout>
    </div>
  );
};

export default HomeLayout;
