import {
  ProForm,
  ProFormInstance,
  ProFormList,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
  ProFormUploadDragger,
  StepsForm,
} from '@ant-design/pro-components';
import { FormListActionType } from '@ant-design/pro-form/lib';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Modal, UploadFile, message } from 'antd';
import yaml from 'js-yaml';
import React, { useEffect, useRef, useState } from 'react';
import {
  proFormItemStyleProps,
  proFormSmallItemStyleProps,
  proFormSmallModelWidth,
  proFormStepsFormProps,
} from '../../../../../config/defaultForm';
// import {beforeUploadFile} from "@/utils/common";
// @ts-ignore
import cookie from 'react-cookies';

export type FormValueType = {
  target?: string;
  template?: string;
  type?: string;
  time?: string;
  frequency?: string;
} & Partial<API.ModelVersion>;

export type CreateFormProps = {
  createModalOpen: boolean;
  handleModal: () => void;
  values: Partial<API.ModelVersion>;
  reload: any;
  currentDefaultFieldsData?: Record<string, any>;
};
const waitTime = (time: number = 100) => {
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve(true);
    }, time);
  });
};
// interface ProjectConfig {
//   params: Array<object>;
// }
const CreateForm: React.FC<CreateFormProps> = (props) => {
  const actionFormListRef = useRef<
    FormListActionType<{
      name: string;
    }>
  >();

  const intl = useIntl();
  const [isHasModelFkId, setIsHasModelFkId] = useState<boolean>(false);

  const [dataFormList] = useState<any>([]);
  const dataFormListRef = useRef(dataFormList);
  const [fileList, setFileList] = useState<UploadFile<any>[]>([]);

  // const [form] = Form.useForm<API.ModelVersion>();
  const [current, setCurrent] = useState(0);
  const formRef = useRef<ProFormInstance>();
  const [filePath, setFilePath] = useState('');

  const handleFileChange = ({ file }: { file: UploadFile }) => {
    let curFile: any;

    switch (file.status) {
      case 'uploading':
      case 'done':
        curFile = [file];
        break;

      case 'removed':
      default:
        curFile = [];
        break;
    }

    setFileList([...curFile]);
  };
  useEffect(() => {
    if (props.currentDefaultFieldsData) {
      // 如果是在模型详情新增版本，ModelFkId不可编辑
      console.log(props.values, isHasModelFkId, 'currentDefaultFieldsData');
      setIsHasModelFkId(true);
    } else {
      setIsHasModelFkId(false);
    }
  }, []);
  return (
    <StepsForm<{
      name: string;
    }>
      stepsProps={proFormStepsFormProps.stepsProps}
      current={current}
      onCurrentChange={setCurrent}
      formProps={{
        validateMessages: {
          required: '此项为必填项',
        },
      }}
      stepsFormRender={(dom, submitter) => {
        return (
          <Modal
            title={
              <FormattedMessage id="model_detail.version.table.list.add" defaultMessage="新增" />
            }
            width={proFormSmallModelWidth}
            onCancel={() => {
              setCurrent(0);
              formRef.current?.resetFields();
              setFileList([]);
              props.handleModal();
            }}
            open={props.createModalOpen}
            footer={submitter}
            destroyOnClose
          >
            {dom}
          </Modal>
        );
      }}
    >
      {/* 版本信息 */}
      <StepsForm.StepForm<{
        name: string;
      }>
        className="gn_form"
        name="base"
        formRef={formRef}
        title={
          <FormattedMessage id="model_detail.version.stepForm.base" defaultMessage="版本信息" />
        }
        stepProps={{
          description: (
            <FormattedMessage
              id="model_detail.version.stepForm.base.description"
              defaultMessage="填写版本基础信息"
            />
          ),
        }}
        onFinish={async () => {
          // setFormData(formRef.current?.getFieldsValue());
          await waitTime(500);
          return true;
        }}
      >
        <ProForm.Group>
          {/* //TODO 默认填充模型 无需选择 */}
          <ProFormSelect
            width={proFormSmallItemStyleProps.width}
            name="modelFkId"
            label={
              <FormattedMessage id="model_detail.version.form.modelFkId" defaultMessage="$$$" />
            }
            placeholder={`${intl.formatMessage({
              id: 'common.please_select',
              defaultMessage: '$$$',
            })}${intl.formatMessage({
              id: 'model_detail.version.form.modelFkId',
              defaultMessage: '$$$',
            })}`}
            required={true}
            // initialValue={props.values.modelFkId}
            showSearch
            debounceTime={1000}
            disabled={true}
            // request={async (keyWord) => {
            //   const resp = await postAlgorithmModelGetAlgorithmModelFkSelect({
            //     keyword: keyWord?.keyWords || '',
            //   });
            //   return resp.data.list.map((v: any) => {
            //     return {
            //       label: v.name,
            //       value: v.id,
            //     };
            //   });
            // }}
          />
          <ProFormText
            width={proFormSmallItemStyleProps.width}
            name="name"
            label={<FormattedMessage id="model_detail.version.form.name" defaultMessage="版本号" />}
            placeholder={`${intl.formatMessage({
              id: 'common.please_input',
              defaultMessage: '$$$',
            })}${intl.formatMessage({
              id: 'model_detail.version.form.name',
              defaultMessage: '$$$',
            })}`}
            required={true}
            rules={[
              {
                required: true,
                message: (
                  <FormattedMessage
                    id="model_detail.version.form.required.name"
                    defaultMessage="name is required"
                  />
                ),
              },
            ]}
          />
          <ProFormTextArea
            width={proFormSmallItemStyleProps.width}
            name="remark"
            label={<FormattedMessage id="model_detail.version.form.remark" defaultMessage="备注" />}
            placeholder={`${intl.formatMessage({
              id: 'common.please_input',
              defaultMessage: '$$$',
            })}${intl.formatMessage({
              id: 'model_detail.version.form.remark',
              defaultMessage: '$$$',
            })}`}
            required={false}
            disabled={false}
          />
        </ProForm.Group>
      </StepsForm.StepForm>
      {/* 版本上传 */}
      <StepsForm.StepForm<{
        project_file: string;
      }>
        className="gn_form"
        name="project_file"
        title={
          <FormattedMessage
            id="model_detail.version.stepForm.project_file"
            defaultMessage="版本上传"
          />
        }
        style={{ width: proFormItemStyleProps.width }}
        stepProps={{
          description: (
            <FormattedMessage
              id="model_detail.version.stepForm.project_file.description"
              defaultMessage="上传模型文件"
            />
          ),
        }}
        onFinish={async (values: any) => {
          if ('projectFilePath' in values && values['projectFilePath'].length > 0) {
            let projectFilePath = values['projectFilePath'][0]?.response?.data?.path || '';
            setFilePath(projectFilePath);
          }
          return true;
        }}
      >
        <ProFormUploadDragger
          label={<span className="font-bold">上传模型文件</span>}
          name="projectFilePath"
          action="/api/v1/file/uploadFile"
          max={1}
          fieldProps={{
            name: 'file',
            // beforeUpload: beforeUploadFile,
            data: { path: `models/${Date.now()}` },
            headers: {
              'X-CSRFToken': cookie.load('csrftoken'),
              Authorization: `Bearer ${localStorage.getItem('access') || ''}`,
            },
          }}
        />
        <div style={{ color: '#666666' }}>请上传格式为zip.tar.gz的模型文件</div>
      </StepsForm.StepForm>
      {/* 参数配置 */}
      <StepsForm.StepForm<{
        config: string;
      }>
        className="gn_form"
        name="config"
        title={
          <FormattedMessage id="model_detail.version.stepForm.config" defaultMessage="参数配置" />
        }
        stepProps={{
          description: (
            <FormattedMessage
              id="model_detail.version.stepForm.config.description"
              defaultMessage="参数配置"
            />
          ),
        }}
        onFinish={async (values: any) => {
          setFileList([]);
          let formData = formRef.current?.getFieldsValue();
          if (formData?.modelFkId) {
            await waitTime(500);
            formData.modelConfig = { params: values?.params || [] };
            if (filePath) {
              formData.path = filePath;
            }
            // postModelVersionCreateModelVersion(formData)
            //   .then(() => {
            //     message.success(
            //       intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }),
            //     );
            //     props.handleModal();
            //     props.reload();
            //   })
            //   .catch(() => {
            //     message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
            //     return false;
            //   });
          }
          return true;
        }}
      >
        <ProFormUploadDragger
          width={proFormSmallItemStyleProps.width}
          max={1}
          label={<span className="font-bold">模型配置文件上传</span>}
          value={fileList}
          name="dragger"
          fieldProps={{
            onChange: handleFileChange,
            onRemove: () => {
              let index_ids = actionFormListRef.current?.getList()?.map((v, i) => {
                return i;
              });
              actionFormListRef.current?.remove(index_ids || []);
            },
            beforeUpload: (file) => {
              if (
                !file.name.endsWith('.yaml') &&
                !file.name.endsWith('.yml') &&
                !file.name.endsWith('.json')
              ) {
                message.error('请上传yaml或json文件').then(() => {});
                return false;
              } else {
                let parsedData = {};
                file
                  .text()
                  .then((text) => {
                    if (file.name.endsWith('.yaml') || file.name.endsWith('.yml')) {
                      parsedData = yaml.load(text) as Record<string, unknown>;
                    }
                    if (file.name.endsWith('.json')) {
                      parsedData = JSON.parse(text) as Record<string, unknown>;
                    }
                    if (Object.keys(parsedData).length > 0) {
                      dataFormListRef.current = Object.entries(parsedData).map(([key, value]) => ({
                        name: key,
                        default: value,
                      }));

                      dataFormListRef.current.forEach((v: any, i: number) => {
                        actionFormListRef.current?.add(v, i);
                      });
                    }
                    return true;
                  })
                  .catch(() => {
                    return false;
                  });
              }
            },
          }}
        />

        {/*  // TODO label字重与上面统一, 操作按钮需要与输入框对齐   */}
        <ProFormList
          name="params"
          label={
            <div>
              {' '}
              <span className="font-bold">模型参数</span>
              <p style={{ color: '#666666' }}>
                暂未上传模型配置文件，可根据业务需求手动添加参数字段~
              </p>
            </div>
          }
          actionRef={actionFormListRef}
          itemContainerRender={(doms) => {
            return <ProForm.Group>{doms}</ProForm.Group>;
          }}
          alwaysShowItemLabel
        >
          {() => {
            return (
              <>
                <ProFormText key="name" name="name" label="键名" />
                <ProFormText key="default" name="default" label="默认值" />
              </>
            );
          }}
        </ProFormList>
      </StepsForm.StepForm>
    </StepsForm>
  );
};
export default CreateForm;
