/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-04-08 10:36:06
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-18 15:39:42
 * @FilePath: \general-ai-manage\src\pages\Model\ModelDetail\index.tsx
 * @Description: 模型详情（基础信息展示、模型版本列表）
 * @交互说明
 * 1. 模型版本列表分页展示
 * 2. 新增、查看编辑、设为默认版本、删除（模型版本）功能
 * 3、编辑模型基本信息
 */
import InnerPageBack from '@/components/Back/innerPageBack';
import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import { getModelDetail, getModelVersionList } from '@/services/testApi/model';
import { PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { ProCard, ProDescriptions, ProTable } from '@ant-design/pro-components';
import { Access, FormattedMessage, history, useAccess, useParams } from '@umijs/max';
import { Button } from 'antd';
import { useRef, useState } from 'react';
import { proTableCommonOptions, proTablePaginationOptions } from '../../../../config/defaultTable';
import CreateForm from './components/createForm';

const ModelDetail: React.FC = () => {
  const routeParams = useParams(); // 路由参数读取
  const access = useAccess();
  // const intl = useIntl();
  const actionRef = useRef<ActionType>();

  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  // const [categoryFkIdIds, setCategoryFkIdIds] = useState([]);
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  // const [currentRow, setCurrentRow] = useState<Record<string, any>>({});

  /**
   * @en-US The pop-up window of the distribution update window
   * @zh-CN 分布更新窗口的弹窗
   * */
  // const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);
  // const [showDetail, setShowDetail] = useState<boolean>(false);

  /**新增 编辑 删除 */
  // 新增
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
    } else {
      setCreateModalOpen(true);
    }
  };

  function reloadList() {
    actionRef.current?.reload();
  }

  /**初始化加载 */
  // useEffect(() => {
  //   reloadList();
  // }, []);
  // 模型基本信息
  const ModelDetailColumns = [
    {
      title: <FormattedMessage id="model_index.table.list.name" defaultMessage="$$$" />,
      dataIndex: 'name',
    },
    {
      title: (
        <FormattedMessage id="model_index.table.list.defaultVersionFkId" defaultMessage="$$$" />
      ),
      dataIndex: 'defaultVersionFkId',
    },
    {
      title: <FormattedMessage id="model_index.table.list.updateTime" defaultMessage="$$$" />,
      dataIndex: 'updateTime',
      valueType: 'dateTime',
    },
    {
      title: <FormattedMessage id="model_index.table.list.remark" defaultMessage="$$$" />,
      dataIndex: 'remark',
    },
  ];
  const columns: ProColumns<Record<string, any>>[] = [
    {
      title: <FormattedMessage id="model_detail.version.table.list.name" defaultMessage="版本号" />,
      dataIndex: 'name',
      hideInSearch: true,
      key: 'fixedName',
      fixed: 'left',
      render: (dom, record) => (
        <div>
          <span>{dom}</span>
          <span>
            {record.isEnable && (
              <span
                style={{
                  marginLeft: 8,
                  padding: '2px 5px',
                  background: '#FFFFFF',
                  borderRadius: '20px',
                  color: '#154DDD',
                  fontSize: '12px',
                  border: '1px solid rgba(21,77,221,0.8)',
                }}
                className="default_version_tag"
              >
                默认版本
              </span>
            )}
          </span>
        </div>
      ),
    },
    {
      title: (
        <FormattedMessage id="model_detail.version.table.list.path" defaultMessage="模型地址" />
      ),
      dataIndex: 'path',
      hideInSearch: true,
      width: '40%',
    },
    {
      title: <FormattedMessage id="model_detail.version.table.list.size" defaultMessage="大小" />,
      dataIndex: 'size',
      hideInSearch: true,
    },

    {
      title: (
        <FormattedMessage
          id="model_detail.version.table.list.updateTime"
          defaultMessage="更新时间"
        />
      ),
      dataIndex: 'updateTime',
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      key: 'option',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            // TODO 设为默认交互补充
            {
              key: 'setDefault',
              renderDom: record.isEnable ? (
                <span style={{ color: '#ccc' }}>设为默认</span>
              ) : (
                <Button
                  key="setDefault"
                  type="link"
                  size="small"
                  onClick={() => {
                    // setCurrentRow(record);
                    // history.push('/home/model-detail');
                    // doToDetail(record);
                    // setShowDetail(true);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.setDefault" defaultMessage="设为默认" />
                </Button>
              ),
            },
            {
              key: 'updateDetail',
              renderDom: (
                <Button
                  key="updateDetail"
                  type="link"
                  size="small"
                  onClick={() => {
                    // TODO 编辑在新增联调后实现
                    // setCurrentRow(record);
                    // history.push('/home/model-detail');
                    // doToDetail(record);
                    // setShowDetail(true);
                    // setUpdateModalOpen(true);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.updateDetail" defaultMessage="查看" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <div className="modelIndex_page home_container">
      <ProCard
        style={{ padding: 0, margin: 0, backgroundColor: 'transparent' }}
        bodyStyle={{ padding: 0, margin: 0, backgroundColor: 'transparent' }}
      >
        <InnerPageBack title=""></InnerPageBack>
        <div className="gn_table_descriptions">
          <ProDescriptions
            column={3}
            columns={ModelDetailColumns}
            request={async () => {
              console.log(routeParams, 'id');
              const resp = await getModelDetail({
                id: Number(routeParams.id),
              });
              // postModelVersionGetModelVersionList({modelFkId: 3})
              console.log('model_detail_resp', resp);
              return {
                data: resp.data,
                success: resp.success,
              };
            }}
          ></ProDescriptions>
        </div>
        <ProTable
          className="gn_pro_table"
          headerTitle={<span>版本列表</span>}
          // 标题栏
          toolBarRender={() => [
            <Access
              accessible={access.canUpdate(history.location.pathname)}
              key={`${history.location.pathname}-add`}
            >
              <div className="my-[16px]">
                <Button
                  type="primary"
                  key="primary"
                  onClick={() => {
                    setCreateModalOpen(true);
                  }}
                >
                  <PlusOutlined />
                  <FormattedMessage id="pages.searchTable.new" defaultMessage="New" />
                </Button>
              </div>
            </Access>,
          ]}
          search={false}
          scroll={{ y: proTableCommonOptions.commscrollY, x: proTableCommonOptions.commscrollX }}
          options={{ fullScreen: false, setting: false, density: false, reload: false }}
          actionRef={actionRef}
          rowKey="key"
          onDataSourceChange={(data) => {
            console.log(data, 'onDataSourceChange_data');
            // let CategoryFkIdIds: any = data.map((v) => {
            //   return v.categoryFkId;
            // });
            // setCategoryFkIdIds(CategoryFkIdIds);
          }}
          pagination={{
            ...proTablePaginationOptions,
            pageSize: currentPageSize,
            onChange: (page, pageSize) => setCurrentPageSize(pageSize),
          }}
          columnsState={{
            persistenceKey: 'algorithm_model_list',
            persistenceType: 'localStorage',
          }}
          request={async (params = {}) => {
            const { current, ...rest } = params;
            const reqParams = {
              page: current,
              ...rest,
            };
            let resp = await getModelVersionList({ ...reqParams });
            console.log(resp, 'getModelVersionList_resp');
            return {
              data: resp.data?.results.map((v: Record<string, any>) => {
                return { ...v, key: v.id };
              }),
              success: resp.success,
              total: resp.data.count,
              current: current,
              pageSize: currentPageSize,
            };
          }}
          columns={columns}
        />
      </ProCard>
      <CreateForm
        createModalOpen={createModalOpen}
        handleModal={handleCreateModal}
        reload={reloadList}
      />
    </div>
  );
};

export default ModelDetail;
