// import { postModelCategoryCreateModelCategory } from '@/services/resource/ModelCategory';
import { getDictIndustry } from '@/services/testApi/dict';
import {
  ModalForm,
  ProForm,
  ProFormRadio,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
} from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form } from 'antd';
import React from 'react';
import {
  proFormSmallItemStyleProps,
  proFormSmallModelWidth,
} from '../../../../../config/defaultForm';
// @ts-ignore
export type FormValueType = {
  target?: string;
  template?: string;
  type?: string;
  time?: string;
  frequency?: string;
} & Partial<Record<string, any>>;

export type CreateFormProps = {
  createModalOpen: boolean;
  handleModal: () => void;
  reload: any;
};
const CreateForm: React.FC<CreateFormProps> = (props) => {
  const intl = useIntl();
  const [form] = Form.useForm<Record<string, any>>();

  return (
    <ModalForm<Record<string, any>>
      className="gn_form"
      width={proFormSmallModelWidth}
      title={intl.formatMessage({
        id: 'model_index.create.form.add',
        defaultMessage: '新建',
      })}
      open={props.createModalOpen}
      form={form}
      autoFocusFirstInput
      modalProps={{
        destroyOnClose: true,
        onCancel: () => props.handleModal(),
      }}
      submitTimeout={2000}
      onFinish={async (values) => {
        console.log(values, 'add_finish_values');
        // TODO 对接新增接口
        // postModelCategoryCreateModelCategory(values)
        //   .then(() => {
        //     message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        //     props.reload();
        //   })
        //   .catch(() => {
        //     message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
        //   });
        props.handleModal();
        return true;
      }}
    >
      <ProForm.Group>
        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="name"
          label={<FormattedMessage id="model_index.create.form.name" defaultMessage="名称" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'model_index.create.form.name',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="model_index.create.form.rule.required.name"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        {/* //TODO 按UI效果调整模型分类 */}
        <ProFormRadio.Group
          name="type"
          label={<FormattedMessage id="model_index.create.form.type" defaultMessage="分类" />}
          radioType="button"
          options={['经典算法', '深度学习']}
          required={true}
        />
        <ProFormSelect
          width={proFormSmallItemStyleProps.width}
          name="industry"
          label={<FormattedMessage id="model_index.create.form.industry" defaultMessage="行业" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_select',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'model_index.create.form.industry',
            defaultMessage: '$$$',
          })}`}
          required={true}
          showSearch
          debounceTime={500}
          request={async () => {
            const { data } = await getDictIndustry();
            return data?.results?.map((v: Record<string, any>) => {
              return { ...v, label: v.name, value: v.id };
            });
          }}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="model_index.create.form.rule.required.industry"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormTextArea
          width={proFormSmallItemStyleProps.width}
          name="remark"
          label={<FormattedMessage id="model_index.create.form.remark" defaultMessage="简介" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'model_index.create.form.remark',
            defaultMessage: '$$$',
          })}`}
          required={false}
          disabled={false}
        />
      </ProForm.Group>
    </ModalForm>
  );
};
export default CreateForm;
