/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-04-08 10:36:06
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-18 10:10:40
 * @FilePath: \general-ai-manage\src\pages\Model\ModelRuntimeLib\index.tsx
 * @Description: 模型运行库
 * @交互说明
 * 1. 运行库列表分页展示、关键词检索
 * 2. 新增、编辑、删除（模型运行库）功能
 *
 */
import { CommButton } from '@/components/Button';
import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import { getModelRuntimeLibList } from '@/services/testApi/model';
import { SearchOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { ProCard, ProForm, ProFormText, ProTable } from '@ant-design/pro-components';
import { Access, FormattedMessage, history, useAccess } from '@umijs/max';
import { Button } from 'antd';
import React, { useEffect, useRef, useState } from 'react';
import { proTableCommonOptions, proTablePaginationOptions } from '../../../../config/defaultTable';
import CreateForm from './components/createForm';
import { ReactComponent as ResetIcon } from '/public/home/reset_icon.svg';
import { ReactComponent as SearchIcon } from '/public/home/search_icon.svg';

const ModelRuntimeLib: React.FC = () => {
  const access = useAccess();
  // const intl = useIntl();
  const actionRef = useRef<ActionType>();
  const [querysData, setQuerysData] = useState<Record<string, any>>({}); // 列表查询参数

  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  // const [categoryFkIdIds, setCategoryFkIdIds] = useState([]);
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  const [currentRow, setCurrentRow] = useState<Record<string, any>>({});
  const [form] = ProForm.useForm(); // form 对象

  /**
   * @en-US The pop-up window of the distribution update window
   * @zh-CN 分布更新窗口的弹窗
   * */
  // const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);
  // const [showDetail, setShowDetail] = useState<boolean>(false);

  /**新增 编辑 删除 */
  // 新增
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setCreateModalOpen(true);
    }
  };

  function reloadList() {
    actionRef.current?.reload();
  }
  // 筛选查询
  useEffect(() => {
    if (actionRef) {
      reloadList();
    }
  }, [actionRef, querysData]);
  // TODO 完善列表展示字段
  const columns: ProColumns<Record<string, any>>[] = [
    {
      title: <FormattedMessage id="model_runtimeLib.table.list.name" defaultMessage="$$$" />,
      dataIndex: 'name',
      hideInSearch: true,
      key: 'fixedName',
      fixed: 'left',
    },
    {
      title: (
        <FormattedMessage id="model_runtimeLib.table.list.createTime" defaultMessage="创建时间" />
      ),
      dataIndex: 'createTime',
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: (
        <FormattedMessage id="model_runtimeLib.table.list.updateTime" defaultMessage="更新时间" />
      ),
      dataIndex: 'updateTime',
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      key: 'option',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            // {
            //   key: 'detail',
            //   renderDom: (
            //     <Button
            //       key="detail"
            //       type="link"
            //       size="small"
            //       onClick={() => {
            //         // setCurrentRow(record);
            //         history.push('/home/model-detail');
            //         // doToDetail(record);
            //         // setShowDetail(true);
            //       }}
            //     >
            //       <FormattedMessage id="pages.searchTable.detail" defaultMessage="Update" />
            //     </Button>
            //   ),
            // },
            {
              key: 'update',
              renderDom: (
                <Button
                  key="update"
                  type="link"
                  size="small"
                  onClick={() => {
                    setUpdateModalOpen(true);
                    setCurrentRow(record);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.update" defaultMessage="Update" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <div className="modelIndex_page home_container">
      <ProCard
        style={{ padding: 0, margin: 0, backgroundColor: 'transparent' }}
        bodyStyle={{ padding: 0, margin: 0, backgroundColor: 'transparent' }}
      >
        <ProTable
          className="gn_pro_table"
          headerTitle={
            <div className="gn_table_query_filter">
              <ProForm
                form={form}
                layout="horizontal"
                submitter={{
                  render: () => (
                    <div style={{ textAlign: 'center', marginLeft: 12 }}>
                      <CommButton
                        type="primary"
                        htmlType="submit"
                        prevIcon={<SearchIcon />}
                        buttonLabel="查询"
                      ></CommButton>
                      <CommButton
                        style={{ marginLeft: 12 }}
                        htmlType="button"
                        prevIcon={<ResetIcon />}
                        buttonLabel="重置"
                        onClick={() => {
                          form.resetFields(); // 点击重置按钮时重置表单数据
                          setQuerysData(() => {}); // 清空筛选项
                        }}
                      ></CommButton>
                    </div>
                  ),
                }}
                onFinish={async (values) => {
                  console.log(values, 'filter_finish_values');
                  setQuerysData(() => values);

                  return true;
                }}
              >
                <ProFormText
                  label={
                    <FormattedMessage
                      id="model_runtimeLib.table.list.name"
                      defaultMessage="运行库名称"
                    />
                  }
                  labelClassName="label_set_1"
                  fieldProps={{
                    style: {
                      width: 280,
                    },
                    prefix: <SearchOutlined style={{ color: 'rgba(0,0,0,.25)' }} />,
                  }}
                  name="name"
                  placeholder="请输入运行库名称"
                />
              </ProForm>
            </div>
          }
          // 标题栏
          toolBarRender={() => [
            <Access
              accessible={access.canUpdate(history.location.pathname)}
              key={`${history.location.pathname}-add`}
            >
              <Button
                type="primary"
                key="primary"
                onClick={() => {
                  setCreateModalOpen(true);
                }}
              >
                <FormattedMessage id="pages.searchTable.new" defaultMessage="New" />
              </Button>
            </Access>,
          ]}
          search={false}
          scroll={{ y: proTableCommonOptions.commscrollY, x: proTableCommonOptions.commscrollX }}
          options={{ fullScreen: false, setting: false, density: false, reload: false }}
          actionRef={actionRef}
          rowKey="key"
          onDataSourceChange={(data) => {
            console.log(data, 'onDataSourceChange_data');
            // let CategoryFkIdIds: any = data.map((v) => {
            //   return v.categoryFkId;
            // });
            // setCategoryFkIdIds(CategoryFkIdIds);
          }}
          pagination={{
            ...proTablePaginationOptions,
            pageSize: currentPageSize,
            onChange: (page, pageSize) => setCurrentPageSize(pageSize),
          }}
          columnsState={{
            persistenceKey: 'algorithm_model_list',
            persistenceType: 'localStorage',
          }}
          request={async (params = {}, sort) => {
            const { current, ...rest } = params;
            const reqParams = {
              page: current,
              desc: false,
              orderKey: '',
              ...rest,
            };
            if (sort && Object.keys(sort).length) {
              reqParams.orderKey = Object.keys(sort)[0];
              let sort_select = sort[reqParams.orderKey];
              reqParams.desc = sort_select === 'descend';
            }
            let resp = await getModelRuntimeLibList({ ...reqParams, ...querysData });
            return {
              data: resp.data.results.map((v: Record<string, any>) => {
                return { ...v, key: v.id };
              }),
              success: resp.success,
              total: resp.data.count,
              current: current,
              pageSize: currentPageSize,
            };
          }}
          columns={columns}
        />
      </ProCard>
      <CreateForm
        createModalOpen={createModalOpen}
        values={currentRow || {}}
        handleModal={handleCreateModal}
        reload={reloadList}
      />
    </div>
  );
};

export default ModelRuntimeLib;
