// import { postModelCategoryCreateModelCategory } from '@/services/resource/ModelCategory';
import { useCity } from '@/hooks/useCity';
import { beforeUploadImage } from '@/utils/common';
import {
  ModalForm,
  ProForm,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
  // ProFormDependency,
  ProFormUploadButton,
} from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form } from 'antd';
import React, { useState } from 'react';
import {
  proFormSmallItemStyleProps,
  proFormSmallModelWidth,
} from '../../../../../config/defaultForm';
// @ts-ignore
import cookie from 'react-cookies';
export type FormValueType = {
  target?: string;
  template?: string;
  type?: string;
  time?: string;
  frequency?: string;
} & Partial<API.ModelCategory>;

export type CreateFormProps = {
  createModalOpen: boolean;
  handleModal: () => void;
  values: Partial<API.ModelCategory>;
  reload: any;
};
const CreateForm: React.FC<CreateFormProps> = (props) => {
  const intl = useIntl();
  // const [isAuto, setIsAuto] = useState(true);
  const [form] = Form.useForm<API.ModelCategory>();
  const [cityOptions, setCityOptions] = useState<Record<string, any>[]>([]);
  const { formatProvinceByData, formatCityByProvinceData } = useCity();
  function changeCity(record1, record2) {
    // 汇总城市数据到表单
    console.log(record1, record2, 'changeProvince_record');
  }

  return (
    <ModalForm<API.ModelCategory>
      className="gn_form"
      width={proFormSmallModelWidth}
      title={intl.formatMessage({
        id: 'business.list.table.createForm.add',
        defaultMessage: '新建',
      })}
      open={props.createModalOpen}
      form={form}
      autoFocusFirstInput
      modalProps={{
        destroyOnClose: true,
        onCancel: () => props.handleModal(),
      }}
      submitTimeout={2000}
      onFinish={async (values) => {
        console.log(values, 'add_finish_values');
        // TODO 对接新增接口
        // postModelCategoryCreateModelCategory(values)
        //   .then(() => {
        //     message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        //     props.reload();
        //   })
        //   .catch(() => {
        //     message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
        //   });
        props.handleModal();
        return true;
      }}
    >
      <ProForm.Group>
        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="name"
          label={<FormattedMessage id="business.list.table.form.name" defaultMessage="名称" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.name',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.name"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />

        <ProFormSelect
          width={proFormSmallItemStyleProps.column2Width / 2 - 8}
          name="province"
          label={<FormattedMessage id="business.list.table.form.province" defaultMessage="省份" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_select',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.province',
            defaultMessage: '$$$',
          })}`}
          required={true}
          showSearch
          debounceTime={500}
          request={() => {
            const respDataList = formatProvinceByData();
            return respDataList;
          }}
          onChange={(_, record2) => {
            form.setFieldValue('city', null); // 先清空城市
            setCityOptions(() => formatCityByProvinceData(record2));
          }}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.province"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormSelect
          width={proFormSmallItemStyleProps.column2Width / 2 - 8}
          name="city"
          label={<FormattedMessage id="business.list.table.form.city" defaultMessage="城市" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_select',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.city',
            defaultMessage: '$$$',
          })}`}
          required={true}
          showSearch
          debounceTime={500}
          options={cityOptions}
          onChange={changeCity}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.city"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="address"
          label={<FormattedMessage id="business.list.table.form.address" defaultMessage="地址" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.address',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.address"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="industry"
          label={<FormattedMessage id="business.list.table.form.industry" defaultMessage="行业" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.industry',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.industry"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="contacts"
          label={
            <FormattedMessage id="business.list.table.form.contacts" defaultMessage="联系人" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.contacts',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.contacts"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="contactWay"
          label={
            <FormattedMessage id="business.list.table.form.contactWay" defaultMessage="联系方式" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.contactWay',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.contactWay"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
        <ProFormTextArea
          width={proFormSmallItemStyleProps.width}
          name="remark"
          label={<FormattedMessage id="business.list.table.form.remark" defaultMessage="简介" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'business.list.table.form.remark',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.remark"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
          disabled={false}
        />
        {/* // TODO level3 按UI实际效果调整上传logo & 改用上传base64格式编码 换手动上传  */}
        <ProFormUploadButton
          width={proFormSmallItemStyleProps.width}
          max={1}
          action="/api/v1/file/uploadImage"
          name="logo"
          label={<FormattedMessage id="business.list.table.form.logo" defaultMessage="logo" />}
          fieldProps={{
            name: 'file',
            listType: 'picture-card',
            beforeUpload: beforeUploadImage,
            data: { path: 'user/avatar' },
            headers: {
              'X-CSRFToken': cookie.load('csrftoken'),
              'X-Token': `${localStorage.getItem('access') || ''}`,
            },
          }}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="business.list.table.form.rule.required.logo"
                  defaultMessage="name is required"
                />
              ),
            },
          ]}
        />
      </ProForm.Group>
    </ModalForm>
  );
};
export default CreateForm;
