/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-04-07 14:02:00
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-04-19 09:28:53
 * @FilePath: \general-ai-manage\src\pages\BusinessProject\BusinessProject.tsx
 * @Description: 企业项目首页
 * @交互说明
 * 1. 统计数据展示
 * 2. 企业列表不分页展示、关键词检索
 * 3. 新增、编辑、删除（企业）功能
 * # 省市二级联动，使用city数据源
 * # 企业logo添加需要上传base64编码（小图标适用）
 *
 */
import { CommButton } from '@/components/Button';
import { ReactComponent as BusinessBannerLogo } from '/public/home/business_banner_logo.svg';
import { ReactComponent as BusinessHeader1 } from '/public/home/business_header_1.svg';
import { ReactComponent as BusinessHeader2 } from '/public/home/business_header_2.svg';
import { ReactComponent as BusinessHeader3 } from '/public/home/business_header_3.svg';
import { ReactComponent as PlusIcon } from '/public/home/plus_icon.svg';
import { ReactComponent as ResetIcon } from '/public/home/reset_icon.svg';
import { ReactComponent as SearchIcon } from '/public/home/search_icon.svg';

// device_count_icon model_count_icon
import IsDelete from '@/components/TableActionCard/isDelete';
import { getBusinessProject } from '@/services/testApi/businessProject';
import { EditOutlined, SearchOutlined } from '@ant-design/icons';
import { ProCard, ProForm, ProFormText, ProList } from '@ant-design/pro-components';
import { FormattedMessage } from '@umijs/max';
import React, { useEffect, useState } from 'react';
import { proIconForTableActionStyle } from '../../../../config/defaultIcon';
import BusinessCard from './components/businessCard';
import CreateForm from './components/createForm';
import './index.less';

type headerItemsProps = {
  title: string;
  count: number;
  icon: string | React.ReactNode;
};
// TODO 补充图标 背景图
const headerItems: headerItemsProps[] = [
  {
    title: '企业总数',
    count: 26,
    icon: <BusinessHeader1></BusinessHeader1>,
  },
  {
    title: '模型应用',
    count: 32,
    icon: <BusinessHeader2></BusinessHeader2>,
  },
  {
    title: '设备总量',
    count: 53,
    icon: <BusinessHeader3></BusinessHeader3>,
  },
];

const BusinessProject: React.FC = () => {
  /**state */
  const [businessProjectList, setBusinessProjectList] = useState<Record<string, any>[]>([]); // 列表数据
  const [querysData, setQuerysData] = useState<Record<string, any>>({}); // 列表查询参数
  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false); // 创建新增窗口是否打开
  // const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false); // 更新窗口是否打开
  const [currentRow, setCurrentRow] = useState<Record<string, any>>();
  const [form] = ProForm.useForm(); // form 对象
  /**新增 编辑 删除 */
  // 新增
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
      setCurrentRow(undefined);
    } else {
      setCreateModalOpen(true);
    }
  };

  // 将数据组装成reactDom
  function toListDomByData(record) {
    let startList = [
      {
        isAdd: true,
      },
      ...record,
    ];
    let finalList = startList.map((item) => ({
      content: item?.isAdd ? (
        <div
          onClick={handleCreateModal}
          className="flex flex-col items-center justify-center w-full bp_card_box"
        >
          <span className="plus_icon">
            <PlusIcon></PlusIcon>
          </span>
          {<FormattedMessage id="business.list.table.createForm.add" defaultMessage="新建" />}
        </div>
      ) : (
        <BusinessCard
          info={item}
          renderActions={[
            // TODO 统一调整样式 按 UI效果
            {
              key: 'update',
              renderDom: (
                <div
                  className="action_item_box"
                  onClick={(e) => {
                    e.stopPropagation();
                    // setUpdateModalOpen(true);
                    setCurrentRow(record);
                  }}
                >
                  <EditOutlined
                    key="update"
                    style={{
                      color: 'rgba(21, 77, 221, 1)',
                      ...proIconForTableActionStyle,
                    }}
                  />
                  <span>资料编辑</span>
                </div>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <div className="action_item_box">
                  <IsDelete
                    buttonType="deleteIcon"
                    deleteNextText="删除项目"
                    deleteApi={() => {
                      // TODO 调用删除接口
                      // handleDestroy(record).then(() => {});
                    }}
                  />
                </div>
              ),
            },
          ]}
        ></BusinessCard>
      ),
    }));
    setBusinessProjectList(finalList);
    console.log(finalList, 'toListDomByData_finalList');
  }
  // 企业列表数据api
  async function fetchData() {
    const res = await getBusinessProject({ page: 1, pageSize: 10, ...querysData });
    if (res.success) {
      toListDomByData(res.data.results);
    }
  }

  function reloadList() {
    fetchData();
  }

  // 初始化加载 & 筛选查询
  useEffect(() => {
    fetchData();
  }, [querysData]);

  return (
    <div className="businessProject_page home_container">
      <header className="flex items-center justify-between px-[32px]">
        <ul className="flex items-center banner_left">
          {headerItems.map((item, index) => {
            return (
              <li className="flex items-center" key={index}>
                <span className="info_icon">{item.icon}</span>
                <div className="info_body">
                  <p>{item.title}</p>
                  <span>{item.count}</span>
                </div>
              </li>
            );
          })}
        </ul>
        <div className="banner_right">
          <BusinessBannerLogo></BusinessBannerLogo>
        </div>
      </header>
      <ProCard
        style={{ padding: 0, margin: 0, backgroundColor: 'transparent' }}
        bodyStyle={{ padding: 0, margin: 0, backgroundColor: 'transparent' }}
      >
        <div className="gn_table_query_filter">
          <ProForm
            form={form}
            layout="horizontal"
            submitter={{
              render: () => (
                <div style={{ textAlign: 'center', marginLeft: 12 }}>
                  <CommButton
                    type="primary"
                    htmlType="submit"
                    prevIcon={<SearchIcon />}
                    buttonLabel="查询"
                  ></CommButton>
                  <CommButton
                    style={{ marginLeft: 12 }}
                    htmlType="button"
                    prevIcon={<ResetIcon />}
                    buttonLabel="重置"
                    onClick={() => {
                      form.resetFields(); // 点击重置按钮时重置表单数据
                      setQuerysData(() => {}); // 清空筛选项
                    }}
                  ></CommButton>
                </div>
              ),
            }}
            onFinish={async (values) => {
              console.log(values, 'filter_finish_values');
              setQuerysData(() => values);

              return true;
            }}
          >
            <ProFormText
              label="企业名称"
              labelClassName="label_set_1"
              fieldProps={{
                style: {
                  width: 280,
                },
                prefix: <SearchOutlined style={{ color: 'rgba(0,0,0,.25)' }} />,
              }}
              name="name"
              placeholder="请输入企业名称"
            />
          </ProForm>
        </div>
        <ProList<any>
          className="gn"
          ghost={true}
          itemCardProps={{
            ghost: true,
            bodyStyle: { padding: 0, margin: 0 },
          }}
          cardProps={{
            bodyStyle: {
              background: 'transparent',
              margin: '-4px 0',
            },
          }}
          pagination={false}
          rowSelection={false}
          grid={{ gutter: 16, xs: 1, md: 2, lg: 3, xl: 4, xxl: 5 }}
          metas={{
            content: {},
          }}
          dataSource={businessProjectList}
        />
      </ProCard>
      <CreateForm
        createModalOpen={createModalOpen}
        values={currentRow || {}}
        handleModal={handleCreateModal}
        reload={reloadList}
      />
      {/* <CreateForm
        createModalOpen={updateModalOpen}
        values={currentRow || {}}
        handleModal={handleCreateModal}
        reload={reloadList}
      /> */}
    </div>
  );
};

export default BusinessProject;
