// import Footer from '@/components/Footer';
import zhCN from '@/locales/zh-CN';
import { postBaseLogin } from '@/services/system/Base';
import { postMenuGetMenu } from '@/services/system/Menu';
import { getAllRouteNameTile, replaceMenuWithRoutesData } from '@/utils/common';
import { getLocale } from '@@/exports';
import { addLocale } from '@@/plugin-locale';

import { LockOutlined, UserOutlined } from '@ant-design/icons';
import {
  LoginForm,
  ProConfigProvider,
  ProFormCheckbox,
  ProFormText,
} from '@ant-design/pro-components';

import { useEmotionCss } from '@ant-design/use-emotion-css';
import { Helmet, SelectLang, history, useIntl, useModel } from '@umijs/max';
import { Alert, Form, message, theme } from 'antd';
import React, { useEffect, useState } from 'react';
import { flushSync } from 'react-dom';
import Settings from '../../../../config/defaultSettings';
import './login.less';

// const ActionIcons = () => {
//   const langClassName = useEmotionCss(({ token }) => {
//     return {
//       marginLeft: '8px',
//       color: 'rgba(0, 0, 0, 0.2)',
//       fontSize: '24px',
//       verticalAlign: 'middle',
//       cursor: 'pointer',
//       transition: 'color 0.3s',
//       '&:hover': {
//         color: token.colorPrimaryActive,
//       },
//     };
//   });

//   return (
//     <>
//       <AlipayCircleOutlined key="AlipayCircleOutlined" className={langClassName} />
//       <TaobaoCircleOutlined key="TaobaoCircleOutlined" className={langClassName} />
//       <WeiboCircleOutlined key="WeiboCircleOutlined" className={langClassName} />
//     </>
//   );
// };

const Lang = () => {
  const langClassName = useEmotionCss(({ token }) => {
    return {
      display: 'none',
      width: 42,
      height: 42,
      lineHeight: '42px',
      position: 'fixed',
      right: 16,
      // zIndex: 99,
      borderRadius: token.borderRadius,
      ':hover': {
        backgroundColor: token.colorBgTextHover,
      },
    };
  });

  return (
    <div className={langClassName} data-lang>
      {SelectLang && <SelectLang />}
    </div>
  );
};

const LoginMessage: React.FC<{
  content: string;
}> = ({ content }) => {
  return (
    <Alert
      style={{
        marginBottom: 24,
      }}
      message={content}
      type="error"
      showIcon
    />
  );
};

const Login: React.FC = () => {
  const [userLoginState, setUserLoginState] = useState<API.LoginResult>({});
  const [type] = useState<string>('account');
  const { initialState, setInitialState } = useModel('@@initialState');
  const { token } = theme.useToken();
  // const [captcha, setCaptcha] = useState<string>('');
  // const [captchaId, setCaptchaId] = useState<string>('');
  const [loginLoading, setLoginLoading] = useState<boolean>(false);

  const containerClassName = useEmotionCss(() => {
    return {
      display: 'flex',
      flexDirection: 'column',
      height: '100vh',
      overflow: 'auto',
      backgroundImage:
        "url('https://mdn.alipayobjects.com/yuyan_qk0oxh/afts/img/V-_oS6r-i7wAAAAAAAAAAAAAFl94AQBr')",
      backgroundSize: '100% 100%',
    };
  });

  const intl = useIntl();
  // const refreshCaptcha = () => {
  //   postBaseCaptcha().then((r: API.Response) => {
  //     let resp_data: API.SysCaptchaResponse = r.data;
  //     setCaptcha(resp_data?.picPath || '');
  //     setCaptchaId(resp_data?.captchaId || '');
  //   });
  // };

  // useEffect(() => {
  //   refreshCaptcha();
  // }, []);
  const fetchUserInfo = async () => {
    const userInfo = await initialState?.fetchUserInfo?.();
    const menus = await postMenuGetMenu();
    if (userInfo) {
      // console.log("fetchUserInfo_userInfo", userInfo);
      if (getLocale() === 'zh-CN') {
        let localData = getAllRouteNameTile(menus.data.routes, '');
        let localRes: any = {};
        localData.forEach((v) => {
          localRes[`menu${v.name}`] = v.title;
        });
        console.log(localRes);
        addLocale('zh-CN', localRes, {
          momentLocale: 'zh-CN',
          antd: zhCN,
        });
      }
      flushSync(() => {
        setInitialState((s) => ({
          ...s,
          currentUser: userInfo,
          menuData: replaceMenuWithRoutesData(menus.data.routes),
        }));
      });
    }
  };

  const handleSubmit = async (values: API.Login) => {
    try {
      // 登录
      const msg = await postBaseLogin({ ...values });
      // const msg = await login({ ...values, type });
      if (msg.success === true) {
        // const defaultLoginSuccessMessage = intl.formatMessage({
        //   id: 'pages.login.success',
        //   defaultMessage: '登录成功！',
        // });
        //
        localStorage.setItem('access', msg.data?.token || '');
        fetchUserInfo().then(() => {
          const urlParams = new URL(window.location.href).searchParams;
          console.log('fetchUserInfo_redirect', urlParams.get('redirect'));
          history.push(urlParams.get('redirect') || '/');
          // message.success('登录成功！');
        });
        return;
        // GetUserProfile().then(r=>{
        //   console.log(223, r)
        // })
      }
      // 如果失败去设置用户错误信息
      setUserLoginState({
        status: msg.success ? 'ok' : 'error',
        type: type,
        currentAuthority: msg.data?.token || '',
      });
    } catch (error) {
      const defaultLoginFailureMessage = intl.formatMessage({
        id: 'pages.login.failure',
        defaultMessage: '登录失败，请重试！',
      });
      message.error(defaultLoginFailureMessage);
      // refreshCaptcha();
    } finally {
      setLoginLoading(false);
    }
  };

  // TODO 测试使用admin
  const [form] = Form.useForm<Record<string, any>>();

  useEffect(() => {
    form.setFieldsValue({ username: 'admin', password: 'Sju2984?' });
    // console.log(form.getFieldsValue(), 'login_form');
  }, []);

  const { status, type: loginType } = userLoginState;

  return (
    <div className={containerClassName}>
      <Helmet>
        <title>
          {intl.formatMessage({
            id: 'menu.login',
            defaultMessage: '登录页',
          })}
          - {Settings.title}
        </title>
      </Helmet>
      <Lang />

      <div
        style={{
          flex: '1',
          // padding: '32px 0',
        }}
        className="loginFrom"
      >
        <div className="loginBox">
          <div className="loginLeft">
            {/* <div className="loginLogo"></div> */}
            <div className="loginBanner"></div>
          </div>
          <div className="loginRight">
            <ProConfigProvider>
              <LoginForm
                form={form}
                containerStyle={{
                  maxWidth: 496,
                  height: 566,
                  padding: 48,
                  paddingTop: 107,
                  borderStartEndRadius: 16,
                  borderEndEndRadius: 16,
                }}
                submitter={{
                  submitButtonProps: {
                    size: 'large',
                    style: {
                      width: '100%',
                      borderRadius: '4px',
                      backgroundColor: '#004FB2',
                    },
                  },
                }}
                title="欢迎登录"
                initialValues={{
                  autoLogin: false,
                }}
                loading={loginLoading}
                onFinish={async (values) => {
                  await handleSubmit(values as API.LoginParams);
                }}
              >
                {status === 'error' && loginType === 'account' && (
                  <LoginMessage
                    content={intl.formatMessage({
                      id: 'pages.login.accountLogin.errorMessage',
                      defaultMessage: '账户或密码错误(admin/ant.design)',
                    })}
                  />
                )}
                {type === 'account' && (
                  <>
                    <ProFormText
                      name="username"
                      fieldProps={{
                        size: 'large',
                        prefix: <UserOutlined className={'prefixIcon'} />,
                      }}
                      placeholder={'用户名:'}
                      rules={[
                        {
                          required: true,
                          message: '请输入用户名!',
                        },
                      ]}
                    ></ProFormText>
                    <ProFormText.Password
                      name="password"
                      fieldProps={{
                        size: 'large',
                        prefix: (
                          <LockOutlined
                            style={{
                              color: token.colorText,
                            }}
                            className={'prefixIcon'}
                          />
                        ),
                      }}
                      placeholder={'密码:'}
                      rules={[
                        {
                          required: true,
                          message: '请输入密码！',
                        },
                      ]}
                    ></ProFormText.Password>
                    {/* <ProFormText
                    name="captcha"
                    fieldProps={{
                      size: 'large',
                      prefix: <KeyOutlined />,
                    }}
                    placeholder={intl.formatMessage({
                      id: 'pages.login.captcha.placeholder',
                      defaultMessage: '验证码:',
                    })}
                    rules={[
                      {
                        required: true,
                        message: (
                          <FormattedMessage
                            id="pages.login.captcha.required"
                            defaultMessage="请输入验证码！"
                          />
                        ),
                      },
                    ]}
                    addonAfter={
                      <Image
                        style={{ backgroundColor: 'white' }}
                        width={120}
                        preview={false}
                        src={captcha}
                        onClick={refreshCaptcha}
                      ></Image>
                    }
                  /> */}
                  </>
                )}
                {status === 'error' && loginType === 'mobile' && (
                  <LoginMessage content="验证码错误" />
                )}
                <div
                  style={{
                    marginBlockEnd: 24,
                  }}
                >
                  <ProFormCheckbox noStyle name="autoLogin">
                    自动登录
                  </ProFormCheckbox>
                  <a
                    style={{
                      float: 'right',
                      color: '#154DDD',
                    }}
                  >
                    忘记密码
                  </a>
                </div>
              </LoginForm>
            </ProConfigProvider>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Login;
